@@ -121,9 +121,9 @@ class ManagerWidget(QtWidgets.QWidget):
         for key, item in self.tree_items.items():
             interval: str = key[2]
 
-            if interval == Interval.MINUTE.value:
+            if interval == Interval.MINUTE:
                 self.minute_child.removeChild(item)
-            elif interval == Interval.HOUR.value:
+            elif interval == Interval.HOUR:
                 self.hour_child.removeChild(item)
             else:
                 self.daily_child.removeChild(item)
@@ -385,7 +385,8 @@ class ManagerWidget(QtWidgets.QWidget):
                 overview.symbol,
                 overview.exchange,
                 overview.interval,
-                overview.end
+                overview.end,
+                self.output
             )
             count += 1
             progress = int(round(count / total * 100, 0))
@@ -402,6 +403,16 @@ class ManagerWidget(QtWidgets.QWidget):
         """"""
         self.showMaximized()
 
+    def output(self, msg: str) -> None:
+        """输出下载过程中的日志"""
+        QtWidgets.QMessageBox.warning(
+            self,
+            "数据下载",
+            msg,
+            QtWidgets.QMessageBox.Ok,
+            QtWidgets.QMessageBox.Ok,
+        )
+
 
 class DataCell(QtWidgets.QTableWidgetItem):
     """"""
@@ -604,7 +615,18 @@ class DownloadDialog(QtWidgets.QDialog):
         start: datetime = start.replace(tzinfo=DB_TZ)
 
         if interval == Interval.TICK:
-            count: int = self.engine.download_tick_data(symbol, exchange, start)
+            count: int = self.engine.download_tick_data(symbol, exchange, start, self.output)
         else:
-            count: int = self.engine.download_bar_data(symbol, exchange, interval, start)
+            count: int = self.engine.download_bar_data(symbol, exchange, interval, start, self.output)
+
         QtWidgets.QMessageBox.information(self, "下载结束", f"下载总数据量：{count}条")
+
+    def output(self, msg: str) -> None:
+        """输出下载过程中的日志"""
+        QtWidgets.QMessageBox.warning(
+            self,
+            "数据下载",
+            msg,
+            QtWidgets.QMessageBox.Ok,
+            QtWidgets.QMessageBox.Ok,
+        )
